@@ -34,8 +34,8 @@ import json, asyncio
 import pika  # sudo pip3 install pika
 from pika.adapters.asyncio_connection import AsyncioConnection
 
-from asl_workflow_engine.logger import init_logging
-from asl_workflow_engine.messaging_exceptions import *
+from local_workflow_engine.logger import init_logging
+from local_workflow_engine.messaging_exceptions import *
 
 def make_future(func, *args, **kwargs):
     """
