@@ -83,12 +83,12 @@ from datetime import datetime, timezone
 from quart import Quart, escape, request, jsonify, abort
 from aioprometheus import Registry, render
 
-from local_workflow_engine.metrics_system import SystemMetrics
+from asl_workflow_engine.metrics_system import SystemMetrics
 
-from local_workflow_engine.logger import init_logging
-from local_workflow_engine.open_tracing_factory import span_context, inject_span
-from local_workflow_engine.arn import *
-from local_workflow_engine.state_engine import MAX_DATA_LENGTH, MAX_STATE_MACHINE_LENGTH
+from asl_workflow_engine.logger import init_logging
+from asl_workflow_engine.open_tracing_factory import span_context, inject_span
+from asl_workflow_engine.arn import *
+from asl_workflow_engine.state_engine import MAX_DATA_LENGTH, MAX_STATE_MACHINE_LENGTH
 try:  # Attempt to use ujson if available https://pypi.org/project/ujson/
     import ujson as json
 except:  # Fall back to standard library json
@@ -144,7 +144,7 @@ class RestAPI(object):
     def __init__(self, state_engine, event_dispatcher, config):
         """
         """
-        self.logger = init_logging(log_name="local_workflow_engine")
+        self.logger = init_logging(log_name="asl_workflow_engine")
         self.logger.info("Creating {}.RestAPI, using {} JSON parser".format(
             __name__, json.__name__
         ))
