@@ -44,7 +44,7 @@ correctly support many of the test cases from the goessner link above.
 """
 from jsonpath import jsonpath  # pip3 install jsonpath
 
-from asl_workflow_engine.asl_exceptions import *
+from local_workflow_engine.asl_exceptions import *
 
 try:  # Attempt to use ujson if available https://pypi.org/project/ujson/
     import ujson as json
