@@ -318,7 +318,7 @@ class TaskDispatcher(object):
         the Message implementation class on event_dispatcher globals(), so
         we can do the import of the Message class from event_dispatcher.
         """
-        from local_workflow_engine.event_dispatcher import Message
+        # from local_workflow_engine.event_dispatcher import Message
 
         """
         Use the value of the “Resource” field to determine the type of the task
@@ -548,8 +548,8 @@ class TaskDispatcher(object):
                         {"LambdaFunctionArn": resource_arn}
                     )
 
-        # def asl_service_openfaas():  # TODO
-        #    print("asl_service_openfaas")
+        def asl_service_openfaas():  # TODO
+           print("asl_service_openfaas")
 
         # def asl_service_fn():  # TODO
         #    print("asl_service_fn")
