@@ -1,9 +1,9 @@
 from asyncio.log import logger
 from unittest import result
-from asl_workflow_engine.logger import init_logging
-from asl_workflow_engine.state_engine import StateEngine
+from local_workflow_engine.logger import init_logging
+from local_workflow_engine.state_engine import StateEngine
 from threading import Timer
-from asl_workflow_engine.arn import parse_arn
+from local_workflow_engine.arn import parse_arn
 import json
 import unittest
 import base64
@@ -18,7 +18,7 @@ ASL = """{
   "States": {
     "SplitVideo": {
       "Type": "Task",
-      "Resource": "arn:aws:lambda:us-east-1:187983511897:function:SplitVideo",
+      "Resource": "arn:aws:openfaas:us-east-1:187983511897:function:SplitVideo",
       "OutputPath":"$$.Execution",
       "ResultPath":"$",
       "Parameters": {
@@ -37,7 +37,7 @@ ASL = """{
         "States": {
           "VideoSolution": {
             "Type": "Task",
-            "Resource": "arn:aws:lambda:us-east-1:187983511897:function:VideoSolution",
+            "Resource": "arn:aws:openfass:us-east-1:187983511897:function:VideoSolution",
             "Parameters":{
                 "WorkDir":"test_video_trans_func/VideoSolution",
                 "Dependencies":["SplitVideo"]
@@ -52,7 +52,7 @@ ASL = """{
       "Type": "Task",
       "InputPath": "$",
       "OutputPath":"$",
-      "Resource": "arn:aws:lambda:us-east-1:187983511897:function:ComposeVideo",
+      "Resource": "arn:aws:openfaas:us-east-1:187983511897:function:ComposeVideo",
       "Parameters":{
         "WorkDir":"test_video_trans_func/ComposeVideo",
         "Dependencies":["VideoSolution"]
@@ -102,6 +102,10 @@ state_engine_config = {
             "state_engine": {
                 "store_url": "ASL_store.json", 
                 "execution_ttl": 500
+            },
+            "metrics":{
+                "implementation":"Prometheus",
+                "namespace":""
             }
       }
 class Params():
@@ -210,19 +214,15 @@ def execute_task_stub(resource_arn, parameters, callback,timeout, context):
         config_context['dependencies_output_key']=['video.mp4']
     with open(configDir,'w+') as config:
         config.write(json.dumps(config_context))      
-    result = {"parameters":parameters,"context":context}
-    print(result)     
-    callback(result)
+    callback(parameters)
 
 def execute_task_openfaas(resource_arn, parameters, callback,timeout, context):
     arn = parse_arn(resource_arn)
     resource = arn["resource"]
-    workdir=parameters['WorkDir']
-    result = {"parameters":parameters,"Output":context}
     func_dir="test_video_trans_func/"+resource+"/"
     print(func_dir)
     mycopyfile("test_video_trans_func/handler_templete.py",func_dir,"handler.py")
-    callback(result)
+    callback( parameters)
 
 def execute_openfaas_request(resource_arn, parameters, callback,timeout, context):
     arn = parse_arn(resource_arn)
@@ -293,20 +293,20 @@ class TestVideoTrans(unittest.TestCase):
         self.event_dispatcher = EventDispatcherStub(state_engine, config)
         self.event_dispatcher.dispatch('{"data":{"item":[1,2,3]}, "context": ' + context + '}')
 
-    def test_execute_task_openfaas(self):
-        state_engine = StateEngine(state_engine_config)
-        # Stub out the real TaskDispatcher execute_task
-        state_engine.task_dispatcher.execute_task = execute_task_openfaas
-        self.event_dispatcher = EventDispatcherStub(state_engine, config)
-        self.event_dispatcher.dispatch('{"data":{"item":[1,2,3]}, "context": ' + context + '}')
+    # def test_execute_task_openfaas(self):
+    #     state_engine = StateEngine(state_engine_config)
+    #     # Stub out the real TaskDispatcher execute_task
+    #     # state_engine.task_dispatcher.execute_task = execute_task_openfaas
+    #     self.event_dispatcher = EventDispatcherStub(state_engine, config)
+    #     self.event_dispatcher.dispatch('{"data":{"item":[1,2,3]}, "context": ' + context + '}')
 
-    def test_async_api(self):
-        cmd='cd test_video_trans_func && faas up -f stack.yaml'
-        os.system(cmd)
-        state_engine = StateEngine(state_engine_config)
-        self.event_dispatcher = EventDispatcherStub(state_engine, config)
-        state_engine.task_dispatcher.execute_task=execute_openfaas_request
-        self.event_dispatcher.dispatch('{"data":{"item":[1,2,3]}, "context": ' + context + '}')
+    # def test_async_api(self):
+    #     cmd='cd test_video_trans_func && faas up -f stack.yaml'
+    #     os.system(cmd)
+    #     state_engine = StateEngine(state_engine_config)
+    #     self.event_dispatcher = EventDispatcherStub(state_engine, config)
+    #     state_engine.task_dispatcher.execute_task=execute_openfaas_request
+    #     self.event_dispatcher.dispatch('{"data":{"item":[1,2,3]}, "context": ' + context + '}')
         
 
 if __name__ == '__main__':
